=================
Bottle Utils Form
=================

Bottle Utils is a collection of loosely related packages for developing web
applications using Bottle_ web framework. This package contains a Form 
processing and validation utility.

.. _Bottle: http://bottlepy.org/
